@@ -74,7 +74,7 @@ List lapjv (NumericMatrix x, NumericVector maxX) {
 }
 
 bool nontrivially_less_than(cost a, cost b) {
-  return a + ((a > ROUND_PRECISION) ? 2 : 0) < b;
+  return a + ((a > ROUND_PRECISION) ? 8 : 0) < b;
 }
 
 /* This function is the jv shortest augmenting path algorithm to solve the 
@@ -105,20 +105,20 @@ cost lap(int16 dim,
    * but avoids compiler warnings */
   cost min = 0, h, umin, usubmin, v2, *d;
   
-  free = new lap_row[dim];       // list of unassigned rows.
-  col_list = new lap_col[dim];    // list of columns to be scanned in various ways.
-  matches = new lap_col[dim];    // counts how many times a row could be assigned.
-  d = new cost[dim];             // 'cost-distance' in augmenting path calculation.
-  predecessor = new lap_row[dim];       // row-predecessor of column in augmenting/alternating path.
+  free = new lap_row[dim];        // List of unassigned rows.
+  col_list = new lap_col[dim];    // List of columns to be scanned in various ways.
+  matches = new lap_col[dim];     // Counts how many times a row could be assigned.
+  d = new cost[dim];              // 'Cost-distance' in augmenting path calculation.
+  predecessor = new lap_row[dim]; // Row-predecessor of column in augmenting/alternating path.
   
-  // init how many times a row will be assigned in the column reduction.
+  // Init how many times a row will be assigned in the column reduction.
   for (i = 0; i != dim; i++) {
     matches[i] = 0;
   }
   
   // COLUMN REDUCTION
-  for (j = dim; j--; ) { // reverse order gives better results.
-    // find minimum cost over rows.
+  for (j = dim; j--; ) { // Reverse order gives better results.
+    // Find minimum cost over rows.
     min = input_cost[0][j];
     imin = 0;
     for (i = 1; i != dim; i++) {
@@ -129,25 +129,25 @@ cost lap(int16 dim,
     }
     v[j] = min;
     if (++matches[imin] == 1) {
-      // init assignment if minimum row assigned for first time.
+      // Init assignment if minimum row assigned for first time.
       rowsol[imin] = j;
       colsol[j] = imin;
-    } else if(v[j] < v[rowsol[imin]]) {
+    } else if (v[j] < v[rowsol[imin]]) {
       int16 j1 = rowsol[imin];
       rowsol[imin] = j;
       colsol[j] = imin;
       colsol[j1] = -1;
     } else {
-      colsol[j] = -1;        // row already assigned, column not assigned.
+      colsol[j] = -1; // Row already assigned, column not assigned.
     }
   }
   
   // REDUCTION TRANSFER
   for (i = 0; i != dim; i++) {
-    if (matches[i] == 0) {     // fill list of unassigned 'free' rows.
+    if (matches[i] == 0) { // Fill list of unassigned 'free' rows.
       free[num_free++] = i;
     } else {
-      if (matches[i] == 1) { // transfer reduction from rows that are assigned once.
+      if (matches[i] == 1) { // Transfer reduction from rows that are assigned once.
         j1 = rowsol[i];
         min = BIG;
         for (j = 0; j < dim; j++) {
@@ -161,22 +161,24 @@ cost lap(int16 dim,
       }
     }
   }
-      
+  
   //   AUGMENTING ROW REDUCTION
   int16 loopcnt = 0;           // do-loop to be done twice.
   do {
     loopcnt++;
     
-    //     scan all free rows.
-    //     in some cases, a free row may be replaced with another one to be scanned next.
+    //     Scan all free rows.
+    //     In some cases, a free row may be replaced with another one to be 
+    //     scanned next.
     k = 0;
     previous_num_free = num_free;
-    num_free = 0;             // start list of rows still free after augmenting row reduction.
+    num_free = 0;             // Start list of rows still free after augmenting
+                              // row reduction.
     while (k < previous_num_free) {
       i = free[k];
       k++;
       
-      //       find minimum and second minimum reduced cost over columns.
+      //     Find minimum and second minimum reduced cost over columns.
       umin = input_cost[i][0] - v[0];
       j1 = 0;
       usubmin = BIG;
@@ -197,75 +199,75 @@ cost lap(int16 dim,
       
       i0 = colsol[j1];
       if (nontrivially_less_than(umin, usubmin)) {
-        //         change the reduction of the minimum column to increase the minimum
-        //         reduced cost in the row to the subminimum.
+        //  Change the reduction of the minimum column to increase the minimum
+        //  reduced cost in the row to the subminimum.
         v[j1] = v[j1] - (usubmin - umin);
       } else if (i0 > -1) {
-          // minimum and subminimum equal.
-          // minimum column j1 is assigned.
-          // swap columns j1 and j2, as j2 may be unassigned.
+          // Minimum and subminimum equal.
+          // Minimum column j1 is assigned.
+          // Swap columns j1 and j2, as j2 may be unassigned.
           j1 = j2;
           i0 = colsol[j2];
       }
         
-      //       (re-)assign i to j1, possibly de-assigning an i0.
+      //    (Re-)assign i to j1, possibly de-assigning an i0.
       rowsol[i] = j1;
       colsol[j1] = i;
       
-      if (i0 > -1) { // minimum column j1 assigned earlier.
+      if (i0 > -1) { // Minimum column j1 assigned earlier.
         if (nontrivially_less_than(umin, usubmin)) {
-          //           put in current k, and go back to that k.
-          //           continue augmenting path i - j1 with i0.
+          // Put in current k, and go back to that k.
+          // Continue augmenting path i - j1 with i0.
           free[--k] = i0;
           Rcpp::checkUserInterrupt();
         } else {
-          //           no further augmenting reduction possible.
-          //           store i0 in list of free rows for next phase.
+          // No further augmenting reduction possible.
+          // Store i0 in list of free rows for next phase.
           free[num_free++] = i0;
         }
       }
     }
-  } while (loopcnt < 2);       // repeat once.
+  } while (loopcnt < 2); // Repeat once.
   
   // AUGMENT SOLUTION for each free row.
   for (f = 0; f != num_free; f++) {
-    free_row = free[f];       // start row of augmenting path.
+    free_row = free[f];       // Start row of augmenting path.
     
     // Dijkstra shortest path algorithm.
-    // runs until unassigned column added to shortest path tree.
+    // Runs until unassigned column added to shortest path tree.
     for(j = dim; j--;) {
       d[j] = input_cost[free_row][j] - v[j];
       predecessor[j] = free_row;
-      col_list[j] = j;        // init column list.
+      col_list[j] = j;        // Init column list.
     }
     
-    low = 0; // columns in 0..low-1 are ready, now none.
-    up = 0;  // columns in low..up-1 are to be scanned for current minimum, now none.
-    // columns in up..dim-1 are to be considered later to find new minimum,
-    // at this stage the list simply contains all columns
+    low = 0; // Columns in 0..low-1 are ready, now none.
+    up = 0;  // Columns in low..up-1 are to be scanned for current minimum, now none.
+    // Columns in up..dim-1 are to be considered later to find new minimum;
+    // at this stage the list simply contains all columns.
     unassignedfound = false;
     do {
-      if (up == low) {       // no more columns to be scanned for current minimum.
+      if (up == low) { // No more columns to be scanned for current minimum.
         last = low - 1;
         
-        // scan columns for up..dim-1 to find all indices for which new minimum occurs.
-        // store these indices between low..up-1 (increasing up).
+        // Scan columns for up..dim-1 to find all indices for which new minimum occurs.
+        // Store these indices between low..up-1 (increasing up).
         min = d[col_list[up++]];
         for (k = up; k < dim; k++) {
           j = col_list[k];
           h = d[j];
           if (h <= min) {
-            if (h < min) {   // new minimum.
-              up = low;      // restart list at index low.
+            if (h < min) {   // New minimum.
+              up = low;      // Restart list at index low.
               min = h;
             }
-            // new index with same minimum, put on undex up, and extend list.
+            // New index with same minimum, put on undex up, and extend list.
             col_list[k] = col_list[up];
             col_list[up++] = j;
           }
         }
-        // check if any of the minimum columns happens to be unassigned.
-        // if so, we have an augmenting path right away.
+        // Check if any of the minimum columns happens to be unassigned.
+        // If so, we have an augmenting path right away.
         for (k = low; k != up; k++) {
           if (colsol[col_list[k]] < 0) {
             endofpath = col_list[k];
@@ -276,7 +278,7 @@ cost lap(int16 dim,
       }
       
       if (!unassignedfound) {
-        // update 'distances' between free_row and all unscanned columns,
+        // Update 'distances' between free_row and all unscanned columns,
         // via next scanned column.
         j1 = col_list[low];
         low++;
@@ -288,14 +290,14 @@ cost lap(int16 dim,
           v2 = input_cost[i][j] - v[j] - h;
           if (v2 < d[j]) {
             predecessor[j] = i;
-            if (v2 == min) { // new column found at same minimum value
+            if (v2 == min) { // New column found at same minimum value
               if (colsol[j] < 0) {
-                // if unassigned, shortest augmenting path is complete.
+                // If unassigned, shortest augmenting path is complete.
                 endofpath = j;
                 unassignedfound = true;
                 break;
               } else {
-              // else add to list to be scanned right away.
+              // Else add to list to be scanned right away.
                 col_list[k] = col_list[up];
                 col_list[up++] = j;
               }
@@ -306,13 +308,13 @@ cost lap(int16 dim,
       }
     } while (!unassignedfound);
     
-    // update column prices.
+    // Update column prices.
     for(k = last + 1; k--;) {
       j1 = col_list[k];
       v[j1] = v[j1] + d[j1] - min;
     }
     
-    // reset row and column assignments along the alternating path.
+    // Reset row and column assignments along the alternating path.
     do {
       i = predecessor[endofpath];
       colsol[endofpath] = i;
@@ -322,7 +324,7 @@ cost lap(int16 dim,
     } while (i != free_row);
   }
   
-  // calculate optimal cost.
+  // Calculate optimal cost.
   cost lapcost = 0;
   for(i = dim; i--;) {
     j = rowsol[i];
@@ -330,11 +332,12 @@ cost lap(int16 dim,
     lapcost = lapcost + input_cost[i][j];
   }
   
-  // free reserved memory.
+  // Free reserved memory.
   delete[] predecessor;
   delete[] free;
   delete[] col_list;
   delete[] matches;
   delete[] d;
+  
   return lapcost;
 }
