@@ -368,6 +368,40 @@ test_that('Clustering information is correctly calculated', {
                MutualClusteringInfo(treeAbc.Defgh, treeAb.Cdefgh),
                tolerance = 1e-05)
   
+  
+  
+  # Different resolution
+  randomBif20 <- structure(list(
+    edge = structure(c(21L, 21L, 22L, 23L, 24L, 25L, 26L, 27L, 28L, 29L, 30L,
+                       31L, 32L, 32L, 31L, 30L, 29L, 33L, 34L, 34L, 33L, 28L, 
+                       35L, 36L, 36L, 35L, 27L, 26L, 37L, 37L, 25L, 38L, 38L,
+                       39L, 39L, 24L, 23L, 22L, 1L, 22L, 23L, 24L, 25L, 26L, 
+                       27L, 28L, 29L, 30L, 31L, 32L, 2L, 14L, 7L, 10L, 33L, 34L,
+                       4L, 6L, 8L, 35L, 36L, 13L, 16L, 18L, 17L, 37L, 5L, 15L,
+                       38L, 11L, 39L, 12L, 19L, 9L, 3L, 20L),
+                     .Dim = c(38L, 2L)), Nnode = 19L,
+    tip.label = c("t1", "t2", "t3", "t4", "t5", "t6", "t7", "t8", "t9", "t10",
+                  "t11", "t12", "t13", "t14", "t15", "t16", "t17", "t18", "t19",
+                  "t20"), br = NULL), class = "phylo")
+  threeAwayPoly <- structure(
+    list(edge = structure(c(21L, 22L, 23L, 24L, 25L, 26L, 27L, 28L, 29L, 29L, 
+                            28L, 27L, 26L, 30L, 30L, 30L, 26L, 31L, 31L, 25L, 
+                            32L, 33L, 33L, 32L, 25L, 25L, 24L, 34L, 34L, 34L,
+                            23L, 22L, 21L, 22L, 23L, 24L, 25L, 26L, 27L, 28L,
+                            29L, 2L, 8L, 14L, 10L, 30L, 13L, 16L, 18L, 31L, 4L,
+                            6L, 32L, 33L, 15L, 20L, 5L, 7L, 17L, 34L, 11L, 12L,
+                            19L, 9L, 3L, 1L), .Dim = c(33L, 2L)),
+         tip.label = c("t1", "t2", "t3", "t4", "t5", "t6", "t7", "t8", "t9",
+                       "t10", "t11", "t12", "t13", "t14", "t15", "t16", "t17",
+                       "t18", "t19", "t20"),
+         Nnode = 14L), class = "phylo")
+  expect_equal(
+    MutualClusteringInfo(threeAwayPoly, randomBif20),
+    MutualClusteringInfo(randomBif20, threeAwayPoly))
+  match <- MutualClusteringInfo(randomBif20, threeAwayPoly, reportMatching = TRUE)
+  expect_equal(c(NA, NA,  1,  2, NA,  3,  7, 11, 10,  4,  6,  9,  8, NA,  5, 12, NA),
+               attr(match, 'matching'))
+  
   library('TreeTools')
   expect_equal(ClusteringEntropy(BalancedTree(64)),
                MutualClusteringInfo(BalancedTree(64), BalancedTree(64)))
